@@ -23,6 +23,21 @@ def _remove_colors(s):
         return ''
     return re.sub('{([A-Z0-9#_]+?)}', '', s)
 
+# https://stackoverflow.com/a/14693789/14470020
+_ansi_escape = re.compile(r'\x1B(?:[@-Z\\-_]|\[[0-?]*[ -/]*[@-~])')
+def _remove_escape(txt):
+    return _ansi_escape.sub('', txt)
+
+# https://stackoverflow.com/a/49986645
+def _replace_emoji(text, replace_char=r'EE'):
+    regrex_pattern = re.compile(pattern = "["
+        u"\U0001F600-\U0001F64F"  # emoticons
+        u"\U0001F300-\U0001F5FF"  # symbols & pictographs
+        u"\U0001F680-\U0001F6FF"  # transport & map symbols
+        u"\U0001F1E0-\U0001F1FF"  # flags (iOS)
+                           "]+", flags = re.UNICODE)
+    return regrex_pattern.sub(replace_char, text)
+
 def _field_date_time_tz():
     t = time.strftime('%y-%m-%d %H:%M:%S%z', time.localtime())
     return t[:-2] if t[-2:] == '00' else t
@@ -47,7 +62,9 @@ __xonsh__.env['PROMPT_FIELDS']['screens'] = _screens
 
 _wrappers = {
     'accent': lambda v: f'{_ACCENT_FG}{v}',
-    'section': lambda v: f'{_SECTION_BG}{_SECTION_FG} {v} {_NOC}{_BARBG}{_BARFG}'
+    'section': lambda v: f'{_SECTION_BG}{_SECTION_FG} {v} {_NOC}{_BARBG}{_BARFG}',
+    'noesc': lambda v: _remove_escape(v),
+    'noesc_strip': lambda v: _remove_escape(v).strip()
 }
 
 for k,f in __xonsh__.env.get('XONTRIB_PROMPT_BAR_WRAPPERS', {}).items():
@@ -89,8 +106,8 @@ def _prompt_bar():
 
     lpc = _format_sections(_LEFT)
     rpc = _format_sections(_RIGHT)
-    lp = _remove_colors(lpc)
-    rp = _remove_colors(rpc)
+    lp = _replace_emoji(_remove_colors(lpc))
+    rp = _replace_emoji(_remove_colors(rpc))
 
     w = ' ' * ( int(cols) - len(lp) - len(rp) )
     
